@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package AWS::IP;
-$AWS::IP::VERSION = '0.02';
+$AWS::IP::VERSION = '0.03';
 use Cache::File;
 use Carp;
 use HTTP::Tiny;
@@ -18,7 +18,7 @@ use constant CACHE_KEY => 'AWS_IPS';
 # ABSTRACT: Get and search AWS IP ranges in a caching, auto-refreshing way
 
 
-sub new
+sub new ($cache_timeout_seconds, [$cache_path])
 {
   croak 'Incorrect number of args passed to AWS::IP->new()' unless @_ >= 2 && @_ <= 3;
   my ($class, $cache_timeout_secs, $cache_path) = @_;
@@ -170,7 +170,7 @@ AWS::IP - Get and search AWS IP ranges in a caching, auto-refreshing way
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head2 SYNOPSIS
 
@@ -187,7 +187,7 @@ version 0.02
     ..
   }
 
-  # get a list of AWS cidrs
+  # get a list of all AWS cidrs
   my $cidrs = $aws->get_cidrs;
 
   for (@$cidrs)
@@ -195,6 +195,17 @@ version 0.02
     ...
   }
 
+  # create your own ip checks
+  use Net::CIDR::Set;
+
+  my $ec2_cidrs = $aws->get_cidrs_by_service('EC2');
+  my $aws_ec2_set = Net::CIDR::Set->new( @$ec2_cidrs );
+
+  if ($aws_ec2_set->contains($ip)
+  {
+    ...
+  }
+
   # time passes, cache has expired
   $aws_ip_data = $aws->get_raw_data; # auto refreshes
 
@@ -210,6 +221,8 @@ Creates a new AWS::IP object and sets up the cache. Requires an number for the c
 
 Boolean method to test if an ip address is from AWS. Optionally takes a service name (AMAZON|EC2|CLOUDFRONT|ROUTE53|ROUTE53_HEALTHCHECKS) and restricts the check to AWS ip addresses for that service.
 
+If you are checking more than one ip address, it's more efficient to pull the CIDRs you want, then use L<Net::CIDR::Set> to test if the ips are present in the CIDRs (see example in SYNOPSIS).
+
 =head2 get_raw_data
 
 Returns the entire raw IP dataset as a Perl data structure.
